@@ -21,7 +21,7 @@
 #include <QColorDialog>
 #include <QIcon>
 #include <QPointer>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QTextBlock>
 #include <QTextDocumentFragment>
 #include <QTextList>
@@ -32,10 +32,10 @@ using namespace std::chrono_literals;
 
 using namespace KPIMTextEdit;
 
-class Q_DECL_HIDDEN RichTextComposerControler::RichTextComposerControlerPrivate
+class Q_DECL_HIDDEN RichTextComposerControler::RichTextComposerControllerPrivate
 {
 public:
-    RichTextComposerControlerPrivate(RichTextComposer *composer, RichTextComposerControler *qq)
+    RichTextComposerControllerPrivate(RichTextComposer *composer, RichTextComposerControler *qq)
         : richtextComposer(composer)
         , q(qq)
     {
@@ -43,7 +43,7 @@ public:
         richTextImages = new RichTextComposerImages(richtextComposer, q);
     }
 
-    ~RichTextComposerControlerPrivate()
+    ~RichTextComposerControllerPrivate()
     {
         delete nestedListHelper;
     }
@@ -78,7 +78,7 @@ public:
     bool painterActive = false;
 };
 
-void RichTextComposerControler::RichTextComposerControlerPrivate::selectLinkText(QTextCursor *cursor) const
+void RichTextComposerControler::RichTextComposerControllerPrivate::selectLinkText(QTextCursor *cursor) const
 {
     // If the cursor is on a link, select the text of the link.
     if (cursor->charFormat().isAnchor()) {
@@ -120,7 +120,7 @@ void RichTextComposerControler::RichTextComposerControlerPrivate::selectLinkText
     }
 }
 
-void RichTextComposerControler::RichTextComposerControlerPrivate::mergeFormatOnWordOrSelection(const QTextCharFormat &format)
+void RichTextComposerControler::RichTextComposerControllerPrivate::mergeFormatOnWordOrSelection(const QTextCharFormat &format)
 {
     QTextCursor cursor = richtextComposer->textCursor();
     QTextCursor wordStart(cursor);
@@ -140,7 +140,7 @@ void RichTextComposerControler::RichTextComposerControlerPrivate::mergeFormatOnW
 
 RichTextComposerControler::RichTextComposerControler(RichTextComposer *richtextComposer, QObject *parent)
     : QObject(parent)
-    , d(new RichTextComposerControlerPrivate(richtextComposer, this))
+    , d(new RichTextComposerControllerPrivate(richtextComposer, this))
 {
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     connect(qApp, &QApplication::paletteChanged, this, &RichTextComposerControler::regenerateColorScheme);
@@ -493,7 +493,7 @@ void RichTextComposerControler::updateLink(const QString &linkUrl, const QString
     d->updateLink(linkUrl, linkText);
 }
 
-void RichTextComposerControler::RichTextComposerControlerPrivate::updateLink(const QString &linkUrl, const QString &linkText)
+void RichTextComposerControler::RichTextComposerControllerPrivate::updateLink(const QString &linkUrl, const QString &linkText)
 {
     q->selectLinkText();
 
@@ -555,7 +555,7 @@ QString RichTextComposerControler::toCleanHtml() const
 
     // Qt inserts various style properties based on the current mode of the editor (underline,
     // bold, etc), but only empty paragraphs *also* have qt-paragraph-type set to 'empty'.
-    static const QString EMPTYLINEREGEX = QStringLiteral("<p style=\"-qt-paragraph-type:empty;(.*)</p>");
+    static const QRegularExpression EMPTYLINEREGEX(QStringLiteral("<p style=\"-qt-paragraph-type:empty;(.*?)</p>"));
 
     static const QString OLLISTPATTERNQT = QStringLiteral("<ol style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px;");
 
@@ -570,19 +570,8 @@ QString RichTextComposerControler::toCleanHtml() const
     // Although we can simply remove the margin-top style property, we still get unwanted results
     // if you have three or more empty lines. It's best to replace empty <p> elements with <p>&nbsp;</p>.
 
-    QRegExp emptyLineFinder(EMPTYLINEREGEX);
-    emptyLineFinder.setMinimal(true);
-
-    // find the first occurrence
-    int offset = emptyLineFinder.indexIn(result, 0);
-    while (offset != -1) {
-        // replace all the matching text with the new line text
-        result.replace(offset, emptyLineFinder.matchedLength(), EMPTYLINEHTML);
-        // advance the search offset to just beyond the last replace
-        offset += EMPTYLINEHTML.length();
-        // find the next occurrence
-        offset = emptyLineFinder.indexIn(result, offset);
-    }
+    // replace all the matching text with the new line text
+    result.replace(EMPTYLINEREGEX, EMPTYLINEHTML);
 
     // fix 2a - ordered lists - MS Outlook treats margin-left:0px; as
     // a non-existing number; e.g: "1. First item" turns into "First Item"
@@ -680,7 +669,7 @@ void RichTextComposerControler::ensureCursorVisible()
     QTimer::singleShot(500ms, richTextComposer()->composerControler(), &RichTextComposerControler::ensureCursorVisibleDelayed);
 }
 
-void RichTextComposerControler::RichTextComposerControlerPrivate::fixupTextEditString(QString &text) const
+void RichTextComposerControler::RichTextComposerControllerPrivate::fixupTextEditString(QString &text) const
 {
     // Remove line separators. Normal \n chars are still there, so no linebreaks get lost here
     text.remove(QChar::LineSeparator);
@@ -876,7 +865,7 @@ void RichTextComposerControler::addQuotes(const QString &defaultQuote)
     cursor.endEditBlock();
 }
 
-QString RichTextComposerControler::RichTextComposerControlerPrivate::addQuotesToText(const QString &inputText, const QString &defaultQuoteSign)
+QString RichTextComposerControler::RichTextComposerControllerPrivate::addQuotesToText(const QString &inputText, const QString &defaultQuoteSign)
 {
     QString answer = inputText;
     answer.replace(QLatin1Char('\n'), QLatin1Char('\n') + defaultQuoteSign);
